@@ -1086,17 +1086,13 @@ class Context():
         # final_slavex (statistical number)
         if self.final_slavex and 'Statistical Analysis from Cascades' in self.final_slavex:
             d = self.final_slavex.get('Statistical Analysis from Cascades', None)
-            count = [d['Number of Cascades']]
+            count = [d['header']['Number of Cascades']]
             with (self.outputdir / 'statistical_analysis_of_data.csv').open('w', newline='') as f:
                 fcsv = csv.writer(f)
                 fcsv.writerow(csv_header.final_slavex_number)
-                for k in ['Collisions', 'Atoms available for pairing', 'Sites available for pairing',
-                 'Pairs identified', 'Pair separations > VCR', 'Unpaired vacant sites',
-                 'Atoms escaping all surfaces', 'Replacement sequences',
-                 'Focuson sequences', 'Truncated trajectories']:
-                    if k in d:
-                        rowdata = [k] + [d[k][v] for v in csv_header.final_slavex_number[1:-1]] + count
-                        fcsv.writerow(rowdata)
+                for k in d['data']:
+                    rowdata = [k['label']] + [k[v] for v in csv_header.final_slavex_number[1:-1]] + count
+                    fcsv.writerow(rowdata)
 
 
 class BlockSeparator():
