@@ -45,8 +45,13 @@ seqn_replacement_seq:\
     SEQN4310_1 _S SEQN4310_2 _S pint _S\
     SEQN4310_3 _S pint _S SEQN4310_4 _S pint SEQN4310_5 _S pint _NL\
     int_multiline_array20\
+    seqn_replacement_large_miller?\
     seqn_replacement_seq_all?
 
+seqn_replacement_large_miller:\
+    "*****Replacement sequences with large Miller indices encountered" _NL\
+    pint _SS "sequences have been omitted.  The maximum omitted length was" fwint5 _NL
+
 seqn_replacement_seq_all:\
     "All sequence directions are in external coordinates" _NL\
     seqn_replacement_seq_all_1?\
@@ -200,6 +205,7 @@ class Transformer(lark_common.Transformer):
             SEQN4310_5 _S
             pint _NL\
             int_multiline_array20\
+            seqn_replacement_large_miller?\
             seqn_replacement_seq_all?
             '''
         obj = {
@@ -210,11 +216,26 @@ class Transformer(lark_common.Transformer):
                     'Long Sequence Threshold':args[9],
                     'Long Sequence Count':args[11],
                     'data':args[12].children}}
-        if len(args) > 13:
-            obj['Analysis of Replacement Sequences']['All sequence'] = args[13]
+        # optional parts
+        for a in args[13:]:
+            obj['Analysis of Replacement Sequences'][a.data] = a.children
+        # if len(args) > 13:
+        #    obj['Analysis of Replacement Sequences']['All sequence'] = args[13]
 
         return obj
 
+    def seqn_replacement_large_miller(self, args):
+        '''
+        "*****Replacement sequences with large Miller indices encountered" _NL\
+        pint _SS "sequences have been omitted.  The maximum omitted length was" fwint5 _NL
+        '''
+        return lark.Tree('Large Miller indicies',
+                {
+                    'Omitted sequences': args[0],
+                    'Maximum omitted length': args[1]
+                    })
+
+
     def seqn_replacement_seq_all(self, args):
         '''"All sequence directions are in external coordinates" _NL\
         seqn_replacement_seq_all_1?\
@@ -224,7 +245,7 @@ class Transformer(lark_common.Transformer):
             obj['Equivalent directions are combined where possible'] = True
             args.pop(0)
         obj['data'] = args[0:]
-        return obj
+        return lark.Tree('All sequence', obj)
 
 
     def seqn_replacement_seq_all_2(self, args):
