@@ -14,6 +14,7 @@ def run(input_,
         cascadedir_form='casc{Cascade:05d}-gr{Group:05d}-num{Number:05d}',
         config_dump_text_blocks=True,
         config_cascade_table_output='BOTH',
+        config_ignore_block_parse_error=False,
         config_block_file_form='00.{blockname:s}.txt',
         config_debug_parser=False):
     '''Dumper operates,
@@ -24,10 +25,11 @@ def run(input_,
     input_ is file stream to parse
     outputdir is string or pathlib.Path object to save output data.
       If outputdir does not exist, try to create it.
-    cascadedir_form is formmatable string to save data for each cascade
-    config_dump_text_blocks controls output 'as-is' text block by each parser
-    config_cascade_table_output chooses whether large output data generated at each cascade
+    cascadedir_form is formattable string to save data for each cascade
+    config_dump_text_blocks: if True, 'as-is' text block is saved, otherwise skipped if it is not needed.
+    config_cascade_table_output: chooses whether large output data generated at each cascade
         is written in one file ('BUNDLE'), in each cascade dir('SEPARATE'),  or both('BOTH')
+    config_ignore_block_parse_error: if True, continue even an error occurs during parsing each block.
     config_block_file_form is fileformat to output parsed block text'''
 
     context = blockseparator.Context(
@@ -35,6 +37,7 @@ def run(input_,
             cascadedir_form,
             config_dump_text_blocks,
             config_cascade_table_output,
+            config_ignore_block_parse_error,
             config_block_file_form,
             config_debug_parser=False)
 
@@ -79,6 +82,11 @@ if __name__ == '__main__':
             '  SEPARATE: output as <root>/<each cascade>/xxx.csv\n'
             '  BUNDLE: output as <root>/xxx_all.csv\n'
             '  BOTH: SEPARATE and BUNDLE')
+    argparser.add_argument(
+            '--abort-on-block-parse-error',
+            help='abort when an error occurs during parsing each block',
+            action='store_true',
+            default=False)
 
     args = argparser.parse_args()
 
@@ -102,9 +110,8 @@ if __name__ == '__main__':
         run(args.input,
             args.output,
             cascadedir_form=args.cascade_directory_format,
-            config_dump_text_blocks = not args.skip_verbose_textblock_output,
-            config_cascade_table_output = args.cascade_table_output)
+            config_dump_text_blocks=not args.skip_verbose_textblock_output,
+            config_cascade_table_output=args.cascade_table_output,
+            config_ignore_block_parse_error=args.ignore_block_parse_error)
     except Exception as e:
-        logging.critical('Error in dumper: {}'.format(e))
-        import traceback
-        traceback.print_exc()
+        logging.critical(str(e), stack_info=True)
