@@ -40,13 +40,15 @@ class DumpWorker(threading.Thread):
             input_,
             outputdir,
             config_dump_text_blocks=True,
-            config_cascade_table_output='BOTH'):
+            config_cascade_table_output='BOTH',
+            config_ignore_block_parse_error=False):
         super().__init__()
 
         self.input_ = input_
         self.outputdir = outputdir
         self.config_dump_text_blocks = config_dump_text_blocks
         self.config_cascade_table_output = config_cascade_table_output
+        self.config_ignore_block_parse_error=config_ignore_block_parse_error
 
     def run(self):
         try:
@@ -54,7 +56,8 @@ class DumpWorker(threading.Thread):
                     self.input_,
                     self.outputdir,
                     config_dump_text_blocks=self.config_dump_text_blocks,
-                    config_cascade_table_output=self.config_cascade_table_output)
+                    config_cascade_table_output=self.config_cascade_table_output,
+                    config_ignore_block_parse_error=self.config_ignore_block_parse_error)
         except Exception as e:
             logger.error(str(e), exc_info=True)
 
@@ -91,7 +94,7 @@ if __name__ == '__main__':
             dumpworker = None
             dumpstarttime = None
             button.config(text='Expand Data')
-            logger.info('Expansion finished')
+            logger.info('**** Expansion finished ****')
     
 
     def runbutton():
@@ -125,13 +128,15 @@ if __name__ == '__main__':
                 logger.info('Expand options')
                 logger.info(f'--skip-verbose-textblock-output: {skip_verbose_textblockout_var.get()}')
                 logger.info(f'--cascade-table-output: {cascade_table_output.get()}')
+                logger.info(f'--abort-on-block-parse-error: {ignore_block_parse_error_var.get()}')
                 logger.info('start expansion')
 
                 dumpworker = DumpWorker(
                         open(inputf, 'rt'),
                         output,
                         config_dump_text_blocks = not skip_verbose_textblockout_var.get(),
-                        config_cascade_table_output = cascade_table_output.get())
+                        config_cascade_table_output = cascade_table_output.get(),
+                        config_ignore_block_parse_error=ignore_block_parse_error_var.get())
             # start thread and change text on the button
             dumpstartepoch = time.time()
             dumpworker.start()
@@ -166,6 +171,7 @@ if __name__ == '__main__':
         # dumper.logger.setLevel(logging.getLevelName(v))
         # old_dumper.logger.setLevel(logging.getLevelName(v))
 
+        # set default logging level (affects on NOSET loggers)
         logging.getLogger().setLevel(v)
 
         logger.info(f'default logging level is {v}')
@@ -184,10 +190,13 @@ if __name__ == '__main__':
 
     # control option
     output_ctrl_frame = tk.LabelFrame(option, text='Output control')
+
+    # --skip-verbose-textblock-output
     skip_verbose_textblockout_var = tk.BooleanVar(output_ctrl_frame, False)
     skip_verbose_textblockout = tk.Checkbutton(output_ctrl_frame,
             variable=skip_verbose_textblockout_var,
             text='Skip output of verbose text block')
+    # --cascade-table-output
     cascade_table_label = tk.Label(output_ctrl_frame, text='Output form for large cascade data tables:')
     cascade_table_output = marlowe_ui.tktool.codedoptionmenu.CodedOptionMenu(
             output_ctrl_frame,
@@ -196,9 +205,18 @@ if __name__ == '__main__':
                 ('SEPARATE', 'SEPARATE: output as <root>/<each cascade>/xxx.csv'), 
                 ('BOTH', 'BOTH: BUNDLE and SEPARATE')])
     cascade_table_output.set('BUNDLE')
+
+    # --abort-on-block-parse-error
+    ignore_block_parse_error_var = tk.BooleanVar(output_ctrl_frame, False)
+    ignore_block_parse_error = tk.Checkbutton(output_ctrl_frame,
+            variable=ignore_block_parse_error_var,
+            text='Ignore errors during parsing each text block')
+
+    # layout widgets
     skip_verbose_textblockout.pack(anchor=tk.W) 
     cascade_table_label.pack(anchor=tk.W)
     cascade_table_output.pack(anchor=tk.E) 
+    ignore_block_parse_error.pack(anchor=tk.W)
 
     output_ctrl_frame.pack(anchor=tk.W, pady=5)
 
@@ -216,7 +234,7 @@ if __name__ == '__main__':
     use_old_parser_var = tk.BooleanVar(option, False)
     use_old_parser = tk.Checkbutton(option,
             variable=use_old_parser_var,
-            text='use old inline parser',
+            text='Use old inline parser',
             command=on_use_old_parser)
 
     use_old_parser.pack(anchor=tk.W, pady=5)
@@ -227,10 +245,11 @@ if __name__ == '__main__':
     h = marlowe_ui.logconsole.QueueHandler(logqueue)
     h.setFormatter(logging.Formatter('%(levelname)s %(name)s: %(message)s'))
     logging.getLogger().addHandler(h)
+    # set WARING level as default logging level
     logging.getLogger().setLevel('WARNING')
     marlowe_ui.logconsole.LogConsoleBinder(logtext, logqueue)
 
-    # initial logging message
+    # set INFO level on this module only, which is not affected by logging.getLogger().setLevel()
     logger.setLevel(logging.INFO)
     logger.info('ml_post_ui is ready. Select input file to be expanded')
 
